module.exports = defineTest({
	description:
		'it does static lookup optimization of internal namespaces, coping with multiple namespaces in one function'
});
